summaryrefslogtreecommitdiffstats
path: root/kviewshell/kviewshell.h
diff options
context:
space:
mode:
Diffstat (limited to 'kviewshell/kviewshell.h')
-rw-r--r--kviewshell/kviewshell.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kviewshell/kviewshell.h b/kviewshell/kviewshell.h
index 3ea6ffef..064c4da1 100644
--- a/kviewshell/kviewshell.h
+++ b/kviewshell/kviewshell.h
@@ -44,7 +44,7 @@ protected slots:
signals:
void restoreDocument(const KURL &url, int page);
- void saveDocumentRestoreInfo(KConfig* config);
+ void saveDocumentRestoreInfo(TDEConfig* config);
protected:
void readSettings();
@@ -54,14 +54,14 @@ protected:
* This method is called when it is time for the app to save its
* properties for session management purposes.
*/
- void saveProperties(KConfig*);
+ void saveProperties(TDEConfig*);
/**
* This method is called when this app is restored. The KConfig
* object points to the session management config file that was saved
* with @ref saveProperties
*/
- void readProperties(KConfig*);
+ void readProperties(TDEConfig*);
void checkActions();
@@ -54,14 +54,14 @@ protected:
/**
- * This method is called when this app is restored. The KConfig
+ * This method is called when this app is restored. The TDEConfig
* object points to the session management config file that was saved
* with @ref saveProperties